@@ -185,7 +185,7 @@ Excellent
     outh = root.render('html', params)
     self.assertEqual(outt, 'ALL YOUR BASE ARE BELONG TO US')
     self.assertEqual(outh, 'ALL YOUR BASE ARE BELONG TO US')
-    self.assertEqual(root.meta.formats, [])
+    self.assertEqual(root.meta.formats, ['data'])
 
   #----------------------------------------------------------------------------
   def test_commandLine(self):
@@ -249,6 +249,34 @@ Excellent
       dict(name='logo.png', cid=True, content='\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\n\x00\x00\x00\n\x01\x03\x00\x00\x00\xb7\xfc]\xfe\x00\x00\x00\x06PLTE\xff\xff\xff\x00\x00\x00U\xc2\xd3~\x00\x00\x00\tpHYs\x00\x00\x0fa\x00\x00\x0fa\x01\xa8?\xa7i\x00\x00\x00\x07tIME\x07\xdd\x07\x07\x12\x04\x11\\\xfd\xd3\x10\x00\x00\x00 IDAT\x08\xd7c\xb0g`\xa8o`x{\x80\xe1\x0c\x18\xdd;\xc0\xf0\xff\x00\x88\x0b\x14\xb4g\x00\x00\xb8(\x0cL\xa6v\x1f\xd8\x00\x00\x00\x00IEND\xaeB`\x82'),
       ])
 
+  #----------------------------------------------------------------------------
+  def test_mako_context(self):
+    root = templatealchemy.Template(
+      source='pkg:templatealchemy:test_data/mako',
+      renderer='mako',
+      extmap={'text': 'txt'})
+    tpl = root.getTemplate('sub')
+    out = tpl.render('html', dict(text='some text'))
+    chk = '''\
+<!DOCTYPE html>
+<html>
+ <head>
+  <title>SubTemplate</title>
+ </head>
+ <body>
+  <h1>Base Common Section</h1>
+  
+
+<p>
+ Some sub-template content: some text.
+</p>
+
+ </body>
+</html>
+'''
+    self.assertMultiLineEqual(out, chk)
+
+
 #------------------------------------------------------------------------------
 # end of $Id$
 #------------------------------------------------------------------------------
